@@ -3,7 +3,8 @@
 /* peony-file-management-properties.c - Functions to create and show the peony preference dialog.
 
    Copyright (C) 2002 Jan Arne Petersen
-
+   Copyright (C) 2018, Tianjin KYLIN Information Technology Co., Ltd.
+   
    The Ukui Library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public License as
    published by the Free Software Foundation; either version 2 of the
@@ -20,6 +21,7 @@
    Boston, MA 02110-1301, USA.
 
    Authors: Jan Arne Petersen <jpetersen@uni-bonn.de>
+   Modified by: liupeng <liupeng@kylinos.cn>
 */
 
 #include <config.h>
@@ -78,7 +80,7 @@ static const char * const default_view_values[] =
 {
     "icon-view",
     "list-view",
-    "compact-view",
+    //"compact-view",
     NULL
 };
 
