@@ -5,6 +5,7 @@
  *
  *  Copyright (C) 1999, 2000 Red Hat, Inc.
  *  Copyright (C) 1999, 2000, 2001 Eazel, Inc.
+ *  Copyright (C) 2018, Tianjin KYLIN Information Technology Co., Ltd.
  *
  *  Peony is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public
@@ -23,6 +24,7 @@
  *  Authors: Elliot Lee <sopwith@redhat.com>
  *           John Sullivan <sullivan@eazel.com>
  *           Darin Adler <darin@bentspoon.com>
+ *  Modified by: liupeng <liupeng@kylinos.cn>
  */
 
 #include <config.h>
@@ -1248,6 +1250,17 @@ got_file_info_for_view_selection_callback (PeonyFile *file,
             }
         }
 
+#if 1
+	if(view_id == NULL)
+	{
+	    char*uri = peony_file_get_uri(file);
+	    if(g_str_has_prefix(uri,"computer:"))
+	    {
+		view_id = g_strdup(PEONY_COMPUTER_VIEW_IID);
+	    }
+	    g_free(uri);
+	}
+#endif
         /* Otherwise, use default */
         if (view_id == NULL)
         {
